@@ -54,11 +54,10 @@ NULL
 #' @rdname module_filter_manager
 ui_filter_manager_panel <- function(id) {
   ns <- NS(id)
-  tags$button(
+  .expand_button(
     id = ns("show_filter_manager"),
-    class = "btn action-button wunder_bar_button",
-    title = "View filter mapping",
-    suppressMessages(icon("fas fa-grip"))
+    label = "Filter Manager",
+    icon = "funnel-fill"
   )
 }
 
@@ -74,7 +73,7 @@ srv_filter_manager_panel <- function(id, slices_global) {
       showModal(
         modalDialog(
           ui_filter_manager(session$ns("filter_manager")),
-          class = "filter_manager_modal",
+          class = "teal-filter-manager-modal",
           size = "l",
           footer = NULL,
           easyClose = TRUE
@@ -193,7 +192,7 @@ srv_module_filter_manager <- function(id, module_fd, slices_global) {
       slices <- slices_global_module()
 
       # Clean up previous filter states and refresh cache of previous module_fd with current
-      if (!is.null(module_fd_previous())) module_fd_previous()$finalize()
+      if (!is.null(module_fd_previous())) module_fd_previous()$destroy()
       module_fd_previous(module_fd())
 
       # Setting filter states from slices_global:
